==> material-ui-shell-1.1.26.tgz: package/es/containers/ImageUploadDialog/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import Typography from '@material-ui/core/Typography';
import Box from '@material-ui/core/Box';
import Button from '@material-ui/core/Button';
import CircularProgress from '@material-ui/core/CircularProgress';
import Cropper from 'react-easy-crop';
import Dialog from '@material-ui/core/Dialog';
import CloudUpload from '@material-ui/icons/CloudUpload';
import DialogActions from '@material-ui/core/DialogActions';
import DialogContent from '@material-ui/core/DialogContent';
import React, { useState, useCallback, useEffect } from 'react';
import Slide from '@material-ui/core/Slide';
import getCroppedImg from './getCropImage';
import useMediaQuery from '@material-ui/core/useMediaQuery';
import { useIntl } from 'react-intl';
import { useTheme } from '@material-ui/core/styles';
import { useAuth } from 'base-shell/lib/providers/Auth';
var Transition = React.forwardRef(function (props, ref) {
  return /*#__PURE__*/React.createElement(Slide, _extends({
    direction: "up"
  }, props, {
    ref: ref
  }));
});

var getFiles = function getFiles(ev) {
  var files = [];

  if (ev.dataTransfer.items) {
    // Use DataTransferItemList interface to access the file(s)
    for (var i = 0; i < ev.dataTransfer.items.length; i++) {
      // If dropped items aren't files, reject them
      if (ev.dataTransfer.items[i].kind === 'file') {
        files.push(ev.dataTransfer.items[i].getAsFile());
      }
    }
  } else {
    // Use DataTransfer interface to access the file(s)
    for (var i = 0; i < ev.dataTransfer.files.length; i++) {
      files.push(ev.dataTransfer.files[i]);
    }
  }

  return files;
};

export default function (_ref) {
  var _ref$isOpen = _ref.isOpen,
      isOpen = _ref$isOpen === void 0 ? false : _ref$isOpen,
      handleClose = _ref.handleClose,
      handleCropSubmit = _ref.handleCropSubmit,
      path = _ref.path,
      cropperProps = _ref.cropperProps;
  var intl = useIntl();
  var theme = useTheme();

  var _useState = useState(false),
      isOver = _useState[0],
      setIsOver = _useState[1];

  var _useState2 = useState(false),
      file = _useState2[0],
      setFile = _useState2[1];

  var fullScreen = useMediaQuery(theme.breakpoints.down('sm'));

  var _useState3 = useState(false),
      croppedImage = _useState3[0],
      setCroppedImage = _useState3[1];

  var _useState4 = useState({
    x: 0,
    y: 0
  }),
      crop = _useState4[0],
      setCrop = _useState4[1];

  var _useState5 = useState(1),
      zoom = _useState5[0],
      setZoom = _useState5[1];

  var _useState6 = useState(null),
      croppedAreaPixels = _useState6[0],
      setCroppedAreaPixels = _useState6[1];

  var _useAuth = useAuth(),
      auth = _useAuth.auth,
      updateAuth = _useAuth.updateAuth;

  var _ref2 = auth || {},
      _ref2$photoURL = _ref2.photoURL,
      currentPhoroURL = _ref2$photoURL === void 0 ? '' : _ref2$photoURL,
      _ref2$displayName = _ref2.displayName,
      currentDisplayName = _ref2$displayName === void 0 ? '' : _ref2$displayName;

  var _useState7 = useState(currentPhoroURL),
      photoURL = _useState7[0],
      setPhotoURL = _useState7[1];

  var onCropComplete = useCallback(function (croppedArea, croppedAreaPixels) {
    setCroppedAreaPixels(croppedAreaPixels);
  }, []);

  var clear = function clear() {
    setCroppedImage(false);
    setFile(false);
    setCroppedAreaPixels(null);
    setIsOver(false);
  };

  useEffect(function () {
    clear();
    return clear;
  }, [path]);
  var showCroppedImage = useCallback( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var _croppedImage;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return getCroppedImg(file, croppedAreaPixels, 0);

          case 3:
            _croppedImage = _context.sent;
            setCroppedImage(_croppedImage);

            if (handleCropSubmit) {
              handleClose();
              handleCropSubmit(_croppedImage);
            }

            _context.next = 11;
            break;

          case 8:
            _context.prev = 8;
            _context.t0 = _context["catch"](0);
            console.error(_context.t0);

          case 11:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, null, [[0, 8]]);
  })), [croppedAreaPixels]);
  return /*#__PURE__*/React.createElement(Dialog, {
    fullScreen: fullScreen,
    open: isOpen,
    onClose: handleClose,
    TransitionComponent: Transition,
    "aria-labelledby": "alert-dialog-title",
    "aria-describedby": "alert-dialog-description"
  }, /*#__PURE__*/React.createElement(DialogContent, null, /*#__PURE__*/React.createElement("div", {
    style: {
      width: '100%',
      height: '100%',
      minWidth: 350,
      padding: 0,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center'
    }
  }, !file && /*#__PURE__*/React.createElement("div", {
    onDrop: function onDrop(e) {
      e.preventDefault();
      var files = getFiles(e);

      if (files.length) {
        var reader = new FileReader();

        reader.onload = function (e) {
          setFile(e.target.result);
        };

        reader.readAsDataURL(files[0]);
      }
    },
    onDragOver: function onDragOver(e) {
      e.preventDefault();
      setIsOver(true);
    },
    onDragLeave: function onDragLeave(e) {
      e.preventDefault();
      setIsOver(false);
    },
    style: {
      width: '100%',
      minHeight: 350,
      borderStyle: 'dashed',
      borderColor: isOver ? 'red' : 'grey',
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      flexDirection: 'column'
    }
  }, /*#__PURE__*/React.createElement(CloudUpload, {
    color: "disabled",
    style: {
      height: 60,
      width: 60
    }
  }), /*#__PURE__*/React.createElement(Typography, {
    variant: "h6",
    style: {
      color: 'grey'
    }
  }, intl.formatMessage({
    id: 'file_upload_text',
    defaultMessage: 'Drop image here or '
  })), /*#__PURE__*/React.createElement("input", {
    style: {
      display: 'none'
    },
    accept: "image/*",
    id: "contained-button-file",
    multiple: true,
    type: "file",
    onChange: function onChange(e) {
      if (e.target.files) {
        var reader = new FileReader();

        reader.onload = function (e) {
          setFile(e.target.result);
        };

        reader.readAsDataURL(e.target.files[0]);
      }
    }
  }), /*#__PURE__*/React.createElement("label", {
    htmlFor: "contained-button-file"
  }, /*#__PURE__*/React.createElement(Button, {
    variant: "contained",
    color: "primary",
    component: "span",
    style: {
      margin: 8
    }
  }, "Upload"))), file && !croppedImage && /*#__PURE__*/React.createElement("div", {
    style: {
      position: 'relative',
      height: 300,
      width: '100%',
      background: 'black'
    }
  }, /*#__PURE__*/React.createElement(Cropper, _extends({
    cropShape: "round",
    showGrid: false,
    image: file,
    crop: crop,
    zoom: zoom,
    aspect: 1,
    onCropChange: setCrop,
    onCropComplete: onCropComplete,
    onZoomChange: setZoom
  }, cropperProps))), croppedImage && /*#__PURE__*/React.createElement(Box, {
    position: "relative",
    display: "inline-flex",
    style: {
      height: 280
    }
  }, /*#__PURE__*/React.createElement(CircularProgress, {
    size: 280,
    variant: "determinate"
  }), /*#__PURE__*/React.createElement(Box, {
    top: 0,
    left: 0,
    bottom: 0,
    right: 0,
    position: "absolute",
    display: "flex",
    alignItems: "center",
    justifyContent: "center"
  }, /*#__PURE__*/React.createElement("img", {
    style: {
      height: 250,
      borderRadius: '50%'
    },
    src: croppedImage,
    alt: "img"
  }))))), /*#__PURE__*/React.createElement(DialogActions, null, /*#__PURE__*/React.createElement(Button, {
    onClick: handleClose,
    color: "secondary"
  }, intl.formatMessage({
    id: 'cancel',
    defaultMessage: 'Cancel'
  })), /*#__PURE__*/React.createElement(Button, {
    disabled: !file,
    onClick: showCroppedImage,
    color: "primary"
  }, intl.formatMessage({
    id: 'save',
    defaultMessage: 'Save'
  }))));
}

==> material-ui-shell-1.2.0.tgz: package/es/containers/ImageUploadDialog/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import Typography from '@material-ui/core/Typography';
import Box from '@material-ui/core/Box';
import Button from '@material-ui/core/Button';
import CircularProgress from '@material-ui/core/CircularProgress';
import Cropper from 'react-easy-crop';
import Dialog from '@material-ui/core/Dialog';
import CloudUpload from '@material-ui/icons/CloudUpload';
import DialogActions from '@material-ui/core/DialogActions';
import DialogContent from '@material-ui/core/DialogContent';
import React, { useState, useCallback, useEffect } from 'react';
import Slide from '@material-ui/core/Slide';
import getCroppedImg from './getCropImage';
import useMediaQuery from '@material-ui/core/useMediaQuery';
import { useIntl } from 'react-intl';
import { useTheme } from '@material-ui/core/styles';
import { useAuth } from 'base-shell/lib/providers/Auth';
var Transition = React.forwardRef(function (props, ref) {
  return /*#__PURE__*/React.createElement(Slide, _extends({
    direction: "up"
  }, props, {
    ref: ref
  }));
});

var getFiles = function getFiles(ev) {
  var files = [];

  if (ev.dataTransfer.items) {
    // Use DataTransferItemList interface to access the file(s)
    for (var i = 0; i < ev.dataTransfer.items.length; i++) {
      // If dropped items aren't files, reject them
      if (ev.dataTransfer.items[i].kind === 'file') {
        files.push(ev.dataTransfer.items[i].getAsFile());
      }
    }
  } else {
    // Use DataTransfer interface to access the file(s)
    for (var i = 0; i < ev.dataTransfer.files.length; i++) {
      files.push(ev.dataTransfer.files[i]);
    }
  }

  return files;
};

export default function (_ref) {
  var _ref$isOpen = _ref.isOpen,
      isOpen = _ref$isOpen === void 0 ? false : _ref$isOpen,
      handleClose = _ref.handleClose,
      handleCropSubmit = _ref.handleCropSubmit,
      path = _ref.path,
      cropperProps = _ref.cropperProps;
  var intl = useIntl();
  var theme = useTheme();

  var _useState = useState(false),
      isOver = _useState[0],
      setIsOver = _useState[1];

  var _useState2 = useState(false),
      file = _useState2[0],
      setFile = _useState2[1];

  var fullScreen = useMediaQuery(theme.breakpoints.down('sm'));

  var _useState3 = useState(false),
      croppedImage = _useState3[0],
      setCroppedImage = _useState3[1];

  var _useState4 = useState({
    x: 0,
    y: 0
  }),
      crop = _useState4[0],
      setCrop = _useState4[1];

  var _useState5 = useState(1),
      zoom = _useState5[0],
      setZoom = _useState5[1];

  var _useState6 = useState(null),
      croppedAreaPixels = _useState6[0],
      setCroppedAreaPixels = _useState6[1];

  var _useAuth = useAuth(),
      auth = _useAuth.auth,
      updateAuth = _useAuth.updateAuth;

  var _ref2 = auth || {},
      _ref2$photoURL = _ref2.photoURL,
      currentPhotoURL = _ref2$photoURL === void 0 ? '' : _ref2$photoURL,
      _ref2$displayName = _ref2.displayName,
      currentDisplayName = _ref2$displayName === void 0 ? '' : _ref2$displayName;

  var _useState7 = useState(currentPhotoURL),
      photoURL = _useState7[0],
      setPhotoURL = _useState7[1];

  var onCropComplete = useCallback(function (croppedArea, croppedAreaPixels) {
    setCroppedAreaPixels(croppedAreaPixels);
  }, []);

  var clear = function clear() {
    setCroppedImage(false);
    setFile(false);
    setCroppedAreaPixels(null);
    setIsOver(false);
  };

  useEffect(function () {
    clear();
    return clear;
  }, [path]);
  var showCroppedImage = useCallback( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var _croppedImage;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return getCroppedImg(file, croppedAreaPixels, 0);

          case 3:
            _croppedImage = _context.sent;
            setCroppedImage(_croppedImage);

            if (handleCropSubmit) {
              handleClose();
              handleCropSubmit(_croppedImage);
            }

            _context.next = 11;
            break;

          case 8:
            _context.prev = 8;
            _context.t0 = _context["catch"](0);
            console.error(_context.t0);

          case 11:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, null, [[0, 8]]);
  })), [croppedAreaPixels]);
  return /*#__PURE__*/React.createElement(Dialog, {
    fullScreen: fullScreen,
    open: isOpen,
    onClose: handleClose,
    TransitionComponent: Transition,
    "aria-labelledby": "alert-dialog-title",
    "aria-describedby": "alert-dialog-description"
  }, /*#__PURE__*/React.createElement(DialogContent, null, /*#__PURE__*/React.createElement("div", {
    style: {
      width: '100%',
      height: '100%',
      minWidth: 350,
      padding: 0,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center'
    }
  }, !file && /*#__PURE__*/React.createElement("div", {
    onDrop: function onDrop(e) {
      e.preventDefault();
      var files = getFiles(e);

      if (files.length) {
        var reader = new FileReader();

        reader.onload = function (e) {
          setFile(e.target.result);
        };

        reader.readAsDataURL(files[0]);
      }
    },
    onDragOver: function onDragOver(e) {
      e.preventDefault();
      setIsOver(true);
    },
    onDragLeave: function onDragLeave(e) {
      e.preventDefault();
      setIsOver(false);
    },
    style: {
      width: '100%',
      minHeight: 350,
      borderStyle: 'dashed',
      borderColor: isOver ? 'red' : 'grey',
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      flexDirection: 'column'
    }
  }, /*#__PURE__*/React.createElement(CloudUpload, {
    color: "disabled",
    style: {
      height: 60,
      width: 60
    }
  }), /*#__PURE__*/React.createElement(Typography, {
    variant: "h6",
    style: {
      color: 'grey'
    }
  }, intl.formatMessage({
    id: 'file_upload_text',
    defaultMessage: 'Drop image here or '
  })), /*#__PURE__*/React.createElement("input", {
    style: {
      display: 'none'
    },
    accept: "image/*",
    id: "contained-button-file",
    multiple: true,
    type: "file",
    onChange: function onChange(e) {
      if (e.target.files) {
        var reader = new FileReader();

        reader.onload = function (e) {
          setFile(e.target.result);
        };

        reader.readAsDataURL(e.target.files[0]);
      }
    }
  }), /*#__PURE__*/React.createElement("label", {
    htmlFor: "contained-button-file"
  }, /*#__PURE__*/React.createElement(Button, {
    variant: "contained",
    color: "primary",
    component: "span",
    style: {
      margin: 8
    }
  }, "Upload"))), file && !croppedImage && /*#__PURE__*/React.createElement("div", {
    style: {
      position: 'relative',
      height: 300,
      width: '100%',
      background: 'black'
    }
  }, /*#__PURE__*/React.createElement(Cropper, _extends({
    cropShape: "round",
    showGrid: false,
    image: file,
    crop: crop,
    zoom: zoom,
    aspect: 1,
    onCropChange: setCrop,
    onCropComplete: onCropComplete,
    onZoomChange: setZoom
  }, cropperProps))), croppedImage && /*#__PURE__*/React.createElement(Box, {
    position: "relative",
    display: "inline-flex",
    style: {
      height: 280
    }
  }, /*#__PURE__*/React.createElement(CircularProgress, {
    size: 280,
    variant: "determinate"
  }), /*#__PURE__*/React.createElement(Box, {
    top: 0,
    left: 0,
    bottom: 0,
    right: 0,
    position: "absolute",
    display: "flex",
    alignItems: "center",
    justifyContent: "center"
  }, /*#__PURE__*/React.createElement("img", {
    style: {
      height: 250,
      borderRadius: '50%'
    },
    src: croppedImage,
    alt: "img"
  }))))), /*#__PURE__*/React.createElement(DialogActions, null, /*#__PURE__*/React.createElement(Button, {
    onClick: handleClose,
    color: "secondary"
  }, intl.formatMessage({
    id: 'cancel',
    defaultMessage: 'Cancel'
  })), /*#__PURE__*/React.createElement(Button, {
    disabled: !file,
    onClick: showCroppedImage,
    color: "primary"
  }, intl.formatMessage({
    id: 'save',
    defaultMessage: 'Save'
  }))));
}
